@@ -1,4 +1,4 @@
-# $Id: PerlSignals.pm 2280 2008-03-10 06:08:01Z rcaputo $
+# $Id: PerlSignals.pm,v 1.8 2004/11/16 07:54:12 teknikill Exp $
 
 # Plain Perl signal handling is something shared by several event
 # loops.  The invariant code has moved out here so that each loop may
@@ -10,7 +10,7 @@ package POE::Loop::PerlSignals;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = do {my($r)=(q$Revision: 2280 $=~/(\d+)/);sprintf"1.%04d",$r};
+$VERSION = do {my@r=(q$Revision: 1.8 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
 
 # Everything plugs into POE::Kernel.
 package POE::Kernel;
@@ -18,10 +18,6 @@ package POE::Kernel;
 use strict;
 use POE::Kernel;
 
-# Flag so we know which signals are watched.  Used to reset those
-# signals during finalization.
-my %signal_watched;
-
 #------------------------------------------------------------------------------
 # Signal handlers/callbacks.
 
@@ -55,14 +51,17 @@ sub _loop_signal_handler_pipe {
 sub loop_watch_signal {
   my ($self, $signal) = @_;
 
-  $signal_watched{$signal} = 1;
-
   # Child process has stopped.
   if ($signal eq 'CHLD' or $signal eq 'CLD') {
-    # We should never twiddle $SIG{CH?LD} under POE, unless we want to
-    # override system() and friends. --hachi
-    # $SIG{$signal} = "DEFAULT";
-    $self->_data_sig_begin_polling();
+
+    # Begin constant polling loop.  Only start it on CHLD or on CLD if
+    # CHLD doesn't exist.
+    $SIG{$signal} = 'DEFAULT';
+    $self->_data_ev_enqueue(
+      $self, $self, EN_SCPOLL, ET_SCPOLL, [ ],
+      __FILE__, __LINE__, undef, time() + 1
+    ) if $signal eq 'CHLD' or not exists $SIG{CHLD};
+
     return;
   }
 
@@ -78,32 +77,9 @@ sub loop_watch_signal {
 
 sub loop_ignore_signal {
   my ($self, $signal) = @_;
-
-  delete $signal_watched{$signal};
-
-  if ($signal eq 'CHLD' or $signal eq 'CLD') {
-    $self->_data_sig_cease_polling();
-    # We should never twiddle $SIG{CH?LD} under poe, unless we want to
-    # override system() and friends. --hachi
-    # $SIG{$signal} = "IGNORE";
-    return;
-  }
-
-  if ($signal eq 'PIPE') {
-    $SIG{$signal} = "IGNORE";
-    return;
-  }
-
   $SIG{$signal} = "DEFAULT";
 }
 
-sub loop_ignore_all_signals {
-  my $self = shift;
-  foreach my $signal (keys %signal_watched) {
-    $self->loop_ignore_signal($signal);
-  }
-}
-
 1;
 
 __END__
@@ -133,6 +109,3 @@ Please see L<POE> for more information about authors, contributors,
 and POE's licensing.
 
 =cut
-
-# rocco // vim: ts=2 sw=2 expandtab
-# TODO - Redocument.
