@@ -1,11 +1,11 @@
-# $Id: Sessions.pm 2245 2007-10-13 05:18:39Z rcaputo $
+# $Id: Sessions.pm,v 1.18 2004/07/16 01:10:16 rcaputo Exp $
 
 # Manage session data structures on behalf of POE::Kernel.
 
-package POE::Resource::Sessions;
+package POE::Resources::Sessions;
 
 use vars qw($VERSION);
-$VERSION = do {my($r)=(q$Revision: 2245 $=~/(\d+)/);sprintf"1.%04d",$r};
+$VERSION = do {my@r=(q$Revision: 1.18 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
 
 # These methods are folded into POE::Kernel;
 package POE::Kernel;
@@ -37,9 +37,11 @@ sub SS_PROCESSES  () { 4 }
 sub SS_ID         () { 5 }
 
 sub _data_ses_preload {
-  $POE::Kernel::poe_kernel->[KR_SESSIONS] = \%kr_sessions;
+   $POE::Kernel::poe_kernel->[KR_SESSIONS] = \%kr_sessions;
 }
 
+use POE::API::ResLoader \&_data_ses_preload;
+
 ### End-run leak checking.
 
 sub _data_ses_finalize {
@@ -103,7 +105,7 @@ sub _data_ses_allocate {
 # garbage collection for the session itself because that should
 # already have happened.
 #
-# TODO This is yet another place where resources will need to register
+# -><- This is yet another place where resources will need to register
 # a function.  Every resource's _data_???_clear_session is called
 # here.
 
@@ -393,7 +395,6 @@ sub _data_ses_collect_garbage {
       "<rc> | handles in use: ", $self->_data_handle_count_ses($session), "\n",
       "<rc> | aliases in use: ", $self->_data_alias_count_ses($session), "\n",
       "<rc> | extra refs    : ", $self->_data_extref_count_ses($session), "\n",
-      "<rc> | pid count     : ", $self->_data_sig_pids_ses($session), "\n",
       "<rc> +---------------------------------------------------\n",
     );
     unless ($ss->[SS_REFCOUNT]) {
@@ -403,7 +404,6 @@ sub _data_ses_collect_garbage {
         "<rc> +---------------------------------------------------\n",
       );
     }
-    _carp "<rc> | called";
   }
 
   if (ASSERT_DATA) {
@@ -414,8 +414,7 @@ sub _data_ses_collect_garbage {
       scalar(keys(%{$ss->[SS_CHILDREN]})) +
       $self->_data_handle_count_ses($session) +
       $self->_data_extref_count_ses($session) +
-      $self->_data_alias_count_ses($session) +
-      $self->_data_sig_pids_ses($session)
+      $self->_data_alias_count_ses($session)
     );
 
     # The calculated reference count really ought to match the one
@@ -446,17 +445,9 @@ sub _data_ses_count {
 # Dispatch _stop to a session, removing it from the kernel's data
 # structures as a side effect.
 
-my %already_stopping;
-
 sub _data_ses_stop {
   my ($self, $session) = @_;
 
-  # Don't stop a session that's already in the throes of stopping.
-  # This can happen with exceptions, during die() in _stop.  It can
-  # probably be removed if exceptions are.
-  return if exists $already_stopping{$session};
-  $already_stopping{$session} = 1;
-
   if (ASSERT_DATA) {
     _trap("stopping a nonexistent session")
       unless exists $kr_sessions{$session};
@@ -507,17 +498,14 @@ sub _data_ses_stop {
   $self->_data_ses_free($session);
 
   # GC the parent, if there is one.
-  if (defined $parent and $parent != $self) {
+  if (defined $parent) {
     $self->_data_ses_collect_garbage($parent);
   }
 
   # Stop the main loop if everything is gone.
-  # XXX - Under Tk this is called twice.  Why?  WHY is it called twice?
   unless (keys %kr_sessions) {
     $self->loop_halt();
   }
-
-  delete $already_stopping{$session};
 }
 
 1;
@@ -526,7 +514,7 @@ __END__
 
 =head1 NAME
 
-POE::Resource::Sessions - manage session data structures for POE::Kernel
+POE::Resources::Sessions - manage session data structures for POE::Kernel
 
 =head1 SYNOPSIS
 
@@ -552,6 +540,3 @@ Probably.
 Please see L<POE> for more information about authors and contributors.
 
 =cut
-
-# rocco // vim: ts=2 sw=2 expandtab
-# TODO - Redocument.
